==> library1.4.1.tar.bz2: library/index.php <==
<?php
  ///////////////////////////////////////////////////
  //Вход в систему
  //2009 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  require_once "utils/chlang_osn.php";

  $button = $TEXT['btn_enter'];
  $action = "login.php";
?>
<html>
<head>
<meta charset="utf-8" />
<meta name="ROBOTS" content="NOINDEX, NOFOLLOW" />
<title><?php echo $TEXT['global-title']; ?></title>
<link rel="StyleSheet" type="text/css" href="skins/base/reader.css" />
<link rel="icon" href="favicon.ico" type="image/x-icon" />
<link rel="shortcut icon" href="favicon.ico" type="image/x-icon" />
</head>
<body>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<div class="horizon">
<table align="center" border="0" class="textPageOsn">
 <tr><td valign="bottom">
  <table align="center" border="0" class="textPage">
   <tr><td class="logontit"><?php echo $TEXT['global-title']; ?></td></tr>
   <tr><td valign="bottom">
     <table border="0" width="60%" align="center">
       <tr><td width="17%" ></td><td></td></tr>
       <tr><td class="logondat"><?php echo $TEXT['login-name']; ?></td><td class="logondat2"><input class="loginform" size=10 maxlength=100 type=text name=login ></td></tr>
       <tr><td class="logondat"><?php echo $TEXT['login-password']; ?></td><td class="logondat2"><input class="loginform" size=10 maxlength=100 type=password name=password ></td></tr>
       <tr><td colspan="2" class="logondat"><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
     </table>
   </td></tr>
   <tr><td class="logonbot"><?php echo $TEXT['global-vertion']; ?></td></tr>
  </table>
 </td></tr>
</table>
</div>
</form>
</body>
</html>

==> library1.19.1.tar.bz2: library/index.php <==
<?php
  ///////////////////////////////////////////////////
  //Вход в систему
  //2009 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  require_once "utils/chlang_osn.php";

  $button = $TEXT['btn_enter'];
  $action = "login.php";
?>
<html>
<head>
<meta charset="utf-8" />
<meta name="ROBOTS" content="NOINDEX, NOFOLLOW" />
<title><?php echo $TEXT['global-title']; ?></title>
<link rel="StyleSheet" type="text/css" href="skins/base/reader.css" />
<link rel="icon" href="favicon.ico" type="image/x-icon" />
<link rel="shortcut icon" href="favicon.ico" type="image/x-icon" />
</head>
<body>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<div class="horizon">
<table align="center" border="0" class="textPageOsn">
 <tr><td valign="bottom">
  <table align="center" border="0" class="textPage">
   <tr><td class="logontit"><?php echo $TEXT['global-title']; ?></td></tr>
   <tr><td valign="bottom">
     <table border="0" width="60%" align="center">
       <tr><td width="17%" ></td><td></td></tr>
       <tr><td class="logondat"><?php echo $TEXT['login-name']; ?></td><td class="logondat2"><input class="loginform" size="10" maxlength="100" type="text" name="login" placeholder="<?php echo $TEXT['login-login']; ?>" /></td></tr>
       <tr><td class="logondat"><?php echo $TEXT['login-password']; ?></td><td class="logondat2"><input class="loginform" size="10" maxlength="100" type="password" name="password" placeholder="<?php echo $TEXT['login-password']; ?>" /></td></tr>
       <tr><td colspan="2" class="logondat"><input class="button2" type="submit" value="<?php echo $button; ?>"></td></tr>
     </table>
   </td></tr>
   <tr><td class="logonbot"><?php echo $TEXT['global-vertion']; ?></td></tr>
  </table>
 </td></tr>
</table>
</div>
</form>
</body>
</html>
